# References

## Acknowledgments

- Eric O. LEBIGOT (EOL), author of the `uncertainties` package, for providing code insight and inspiration.
- Stephen Marks, professor at Pomona College, for useful feedback concerning the interface with optimization routines in `scipy.optimize`.
- Wendell Smith, for updating testing functionality and numerous other useful function updates.
- Jonathan Terhorst, for catching a bug that made derivatives of logarithmic functions (`base != e`) give the wrong answers.
- GitHub user `fhgd` for catching a mis-calculation in `admath.atan2`.

## License

Revised BSD License: <a href="http://opensource.org/licenses/BSD-3-Clause" style="color: #484848;">BSD-3-Clause</a>

> Source:  
<a href="https://pythonhosted.org/mcerp" style="color: #484848;">pythonhosted.org/ad</a>
